package com.xingxi.business.Carts.service.impl;

import com.xingxi.common.core.text.Convert;
import com.xingxi.common.utils.DateUtils;
import com.xingxi.business.Carts.domain.Carts;
import com.xingxi.business.Carts.mapper.CartsMapper;
import com.xingxi.business.Carts.service.ICartsService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 购物车Service业务层处理
 *
 * @author xingxi
 * @date 2025-03-06
 */
@Service
public class CartsServiceImpl implements ICartsService {
    @Resource
    private CartsMapper cartsMapper;

    /**
     * 查询购物车
     *
     * @param id 购物车主键
     * @return 购物车
     */
    @Override
    public Carts selectCartsById(Long id) {
        return cartsMapper.selectCartsById(id);
    }

    /**
     * 查询购物车列表
     *
     * @param Carts 购物车
     * @return 购物车
     */
    @Override
    public List<Carts> selectCartsList(Carts Carts) {
        return cartsMapper.selectCartsList(Carts);
    }

    /**
     * 新增购物车
     *
     * @param Carts 购物车
     * @return 结果
     */
    @Override
    public int insertCarts(Carts Carts) {
        Carts.setCreateTime(DateUtils.getNowDate());
        return cartsMapper.insertCarts(Carts);
    }

    /**
     * 新增购物车
     *
     * @param CartsList 购物车
     * @return 结果
     */
    @Override
    public int batchInsertCarts(List<Carts> CartsList) {
        return cartsMapper.batchInsertCarts(CartsList);
    }

    /**
     * 修改购物车
     *
     * @param Carts 购物车
     * @return 结果
     */
    @Override
    public int updateCarts(Carts Carts) {
        Carts.setUpdateTime(DateUtils.getNowDate());
        return cartsMapper.updateCarts(Carts);
    }

    /**
     * 批量删除购物车
     *
     * @param ids 需要删除的购物车主键
     * @return 结果
     */
    @Override
    public int deleteCartsByIds(String ids) {
        return cartsMapper.deleteCartsByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除购物车信息
     *
     * @param id 购物车主键
     * @return 结果
     */
    @Override
    public int deleteCartsById(Long id) {
        return cartsMapper.deleteCartsById(id);
    }

    /**
     * 逻辑删除购物车
     *
     * @param id 购物车主键
     * @return 结果
     */
    @Override
    public int logicDeleteCartsById(Long id) {
        return cartsMapper.logicDeleteCartsById(id);
    }

    /**
     * 逻辑批量删除购物车
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    @Override
    public int logicDeleteCartsByIds(String[] ids) {
        return cartsMapper.logicDeleteCartsByIds(ids);
    }

    /**
     * 逻辑批量删除购物车
     *
     * @param Carts 购物车
     * @return 结果
     */
    @Override
    public int logicDeleteCartsByCondition(Carts Carts) {
        return cartsMapper.logicDeleteCartsByCondition(Carts);
    }
}
